@@ -13,7 +13,9 @@ import java.net.MalformedURLException;
 import java.net.URL;
 
 import android.app.Activity;
+import android.app.AlertDialog;
 import android.content.Intent;
+import android.content.DialogInterface;
 import android.os.Bundle;
 import android.os.Handler;
 import android.support.v4.app.NavUtils;
@@ -25,6 +27,9 @@ import android.view.View;
 import android.webkit.WebSettings;
 import android.webkit.WebView;
 import android.webkit.WebViewClient;
+import android.webkit.SslErrorHandler;
+import android.net.http.SslError;
+import android.net.Uri;
 import android.widget.Button;
 import android.widget.LinearLayout;
 import android.widget.ProgressBar;
@@ -99,12 +104,19 @@ public class HelpActivity extends Activity {
             if (nativeDownloadedFile(url)) {
                 return true;
             }
+            /* better to open http[s] links in external browser???!!!
+            if (url.startsWith("http")) {
+                Intent i = new Intent(Intent.ACTION_VIEW, Uri.parse(url));
+                startActivity(i);
+                return true;
+            }
+            */
             return false;
         }
         
         @Override
         public void onReceivedError(WebView webview, int errorCode, String description, String failingUrl) {
-            Toast.makeText(HelpActivity.this, "Web error! " + description, Toast.LENGTH_SHORT).show();
+            Toast.makeText(HelpActivity.this, "Web error! " + description, Toast.LENGTH_LONG).show();
         }
         
         @Override
@@ -123,6 +135,32 @@ public class HelpActivity extends Activity {
             pageurl = gwebview.getUrl();
             // Log.i("onPageFinished URL", pageurl);
         }  
+        
+        // this allows links in Help > References to open
+        @Override
+        public void onReceivedSslError(WebView webview, SslErrorHandler handler, SslError err) {
+            // this will ignore all SSL certificate errors but probably prevent app from being accepted by Google
+            // handler.proceed();
+            
+            // ask user if ok to continue
+            final AlertDialog.Builder builder = new AlertDialog.Builder(HelpActivity.this);
+            builder.setTitle("SSL Certificate Error");
+            builder.setMessage(err.toString());
+            builder.setPositiveButton("Continue", new DialogInterface.OnClickListener() {
+                @Override
+                public void onClick(DialogInterface dialog, int which) {
+                    handler.proceed();
+                }
+            });
+            builder.setNegativeButton("Cancel", new DialogInterface.OnClickListener() {
+                @Override
+                public void onClick(DialogInterface dialog, int which) {
+                    handler.cancel();
+                }
+            });
+            final AlertDialog dialog = builder.create();
+            dialog.show();
+        }
     }
 
     // -----------------------------------------------------------------------------
@@ -205,14 +243,17 @@ public class HelpActivity extends Activity {
         // no need???
         // settings.setDomStorageEnabled(true);
 
-        settings.setAllowFileAccess(true);
+        settings.setAllowFileAccess(true); // for file URLs
 
         DisplayMetrics metrics = getResources().getDisplayMetrics();
         // my Nexus 7 has a density of 320
         if (metrics.densityDpi > 300) {
             // use bigger font size for high density screens (default size is 16)
-            gwebview.getSettings().setDefaultFontSize(24);
+            settings.setDefaultFontSize(24);
         }
+        
+        // allow zooming
+        settings.setBuiltInZoomControls(true);
 
         if (firstcall) {
             firstcall = false;
@@ -402,7 +443,7 @@ public class HelpActivity extends Activity {
             connection.connect();
             if (connection.getResponseCode() != HttpURLConnection.HTTP_OK) {
                 outstream.close();
-                return "No HTTP_OK response.";
+                return "Bad HTTP response: " + connection.getResponseCode();
             }
             
             // init info for progress bar
@@ -441,9 +482,9 @@ public class HelpActivity extends Activity {
             if (cancelled) return "Cancelled.";
             
         } catch (MalformedURLException e) {
-            return "Bad URL string: " + urlstring;
+            return "Bad URL string:\n" + urlstring;
         } catch (IOException e) {
-            return "Could not connect to URL: " + urlstring;
+            return "Error connecting to URL:\n" + e.toString();
         }
         return "";  // success
     }
@@ -475,7 +516,7 @@ public class HelpActivity extends Activity {
                             // download succeeded
                             nativeProcessDownload(dfile);
                         } else if (!cancelled) {
-                            Toast.makeText(HelpActivity.this, "Download failed! " + dresult, Toast.LENGTH_SHORT).show();
+                            Toast.makeText(HelpActivity.this, "Download failed! " + dresult, Toast.LENGTH_LONG).show();
                         }
                     }
                 });
