@@ -641,8 +641,6 @@ void OpenZipFile(const char* zippath)
     int scriptfiles = 0;
     int textfiles = 0;                  // includes html files
     int rulefiles = 0;
-    int deprecated = 0;                 // # of .table/tree files
-    std::list<std::string> deplist;     // list of installed deprecated files
     std::list<std::string> rulelist;    // list of installed .rule files
     int err;
 
@@ -718,31 +716,12 @@ void OpenZipFile(const char* zippath)
                     // entry is for some sort of file
                     std::string filename = GetBaseName(name.c_str());
                     if (dirseen) contents += indent;
-
-                    if ( IsRuleFile(filename) && !EndsWith(filename,".rule") ) {
-                        // this is a deprecated .table/tree/colors/icons file
-                        if (EndsWith(filename,".colors") || EndsWith(filename,".icons")) {
-                            // these files are no longer supported and are simply ignored
-                            contents += filename;
-                            contents += indent;
-                            contents += "[ignored]";
-                            // don't add to deprecated list
-                        } else {
-                            // .table/.tree file
-                            contents += filename;
-                            contents += indent;
-                            contents += "[deprecated]";
-                            deprecated++;
-                            // install it into userrules so it can be used below to create a .rule file
-                            std::string outfile = userrules + filename;
-                            if (RuleInstalled(zfile, file_info, outfile)) {
-                                deplist.push_back(filename);
-                            } else {
-                                contents += indent;
-                                contents += "INSTALL FAILED!";
-                            }
-                        }
-
+                    if (EndsWith(filename,".table") || EndsWith(filename,".tree") ||
+                        EndsWith(filename,".colors") || EndsWith(filename,".icons")) {
+                        // these files are no longer supported and are simply ignored
+                        contents += filename;
+                        contents += indent;
+                        contents += "[ignored]";
                     } else {
                         // user can extract file via special "unzip:" link
                         contents += "<a href=\"unzip:";
@@ -820,13 +799,6 @@ void OpenZipFile(const char* zippath)
         contents += relpath;
         contents += ".";
     }
-    if (deprecated > 0) {
-        std::string newrules = CreateRuleFiles(deplist, rulelist);
-        if (newrules.length() > 0) {
-            contents += "<p>Files marked as \"[deprecated]\" have been used to create new .rule files:<br>\n";
-            contents += newrules;
-        }
-    }
     contents += "\n</b></font></body></html>";
 
     // NOTE: The desktop version of Golly will load a pattern if it's in a "simple" zip file
@@ -889,6 +861,11 @@ void OpenFile(const char* path, bool remember)
         Warning("This version of Golly cannot run scripts.");
         return;
     }
+    
+    if (EndsWith(path, ".rle3")) {
+        Warning("This version of Golly cannot open 3D patterns.");
+        return;
+    }
 
     if (IsZipFile(path)) {
         // process zip file
@@ -1010,10 +987,11 @@ bool SavePattern(const std::string& path, pattern_format format, output_compress
 
 // -----------------------------------------------------------------------------
 
+const char* HTML_PREFIX = "GET-";   // prepended to html filename
+bool httpslink = false;
+
 void GetURL(const std::string& url, const std::string& pageurl)
 {
-    const char* HTML_PREFIX = "GET-";   // prepended to html filename
-
 #ifdef ANDROID_GUI
     // LOGI("GetURL url=%s\n", url.c_str());
     // LOGI("GetURL pageurl=%s\n", pageurl.c_str());
@@ -1024,30 +1002,38 @@ void GetURL(const std::string& url, const std::string& pageurl)
 #endif
 
     std::string fullurl;
-    if (url.find("http:") == 0) {
+    if (url.find("http") == 0) {
         fullurl = url;
+        httpslink = url.find("https") == 0;
     } else {
         // relative get, so prepend full prefix extracted from pageurl
         std::string urlprefix = GetBaseName(pageurl.c_str());
-        // replace HTML_PREFIX with "http://" and convert spaces to '/'
+        // replace HTML_PREFIX with "http[s]://" and convert spaces to '/'
         // (ie. reverse what we do below when building filepath)
         urlprefix.erase(0, strlen(HTML_PREFIX));
-        urlprefix = "http://" + urlprefix;
+        if (httpslink) {
+            urlprefix = "https://" + urlprefix;
+        } else {
+            urlprefix = "http://" + urlprefix;
+        }
         std::replace(urlprefix.begin(), urlprefix.end(), ' ', '/');
         urlprefix = urlprefix.substr(0, urlprefix.rfind('/')+1);
         fullurl = urlprefix + url;
     }
 
     std::string filename = GetBaseName(fullurl.c_str());
+    
     // remove ugly stuff at start of file names downloaded from ConwayLife.com
+    /* no longer necessary
     if (filename.find("download.php?f=") == 0 ||
         filename.find("pattern.asp?p=") == 0 ||
         filename.find("script.asp?s=") == 0) {
         filename = filename.substr( filename.find('=')+1 );
     }
+    */
 
     // create full path for downloaded file based on given url;
-    // first remove initial "http://"
+    // first remove initial "http[s]://"
     std::string filepath = fullurl.substr( fullurl.find('/')+1 );
     while (filepath[0] == '/') filepath.erase(0,1);
     if (IsHTMLFile(filename)) {
