@@ -1431,6 +1431,7 @@ void UpdateMenuItems(const char* id)
         jsTickMenuItem("control_autofit", currlayer->autofit);
         jsTickMenuItem("control_hash", currlayer->showhashinfo);
         jsTickMenuItem("control_timing", showtiming);
+        jsTickMenuItem("control_autostop", autostop);
     
     } else if (menu == "Algo_menu") {
         jsTickMenuItem("algo0", currlayer->algtype == 0);
@@ -1447,6 +1448,7 @@ void UpdateMenuItems(const char* id)
         } else {
             EM_ASM( document.getElementById('view_fits').className = 'item_disabled'; );
         }
+        jsTickMenuItem("view_xys", showxystate);
         jsTickMenuItem("view_grid", showgridlines);
         jsTickMenuItem("view_icons", showicons);
         if (currlayer->currfile.length() > 0) {
@@ -1527,6 +1529,7 @@ void DoMenuItem(const char* id)
     if (item == "control_autofit") ToggleAutoFit(); else
     if (item == "control_hash") ToggleHashInfo(); else
     if (item == "control_timing") ToggleTiming(); else
+    if (item == "control_autostop") autostop = !autostop; else
     if (item == "algo0") SetAlgo(0); else
     if (item == "algo1") SetAlgo(1); else
     if (item == "algo2") SetAlgo(2); else
@@ -1548,6 +1551,7 @@ void DoMenuItem(const char* id)
     if (item == "scale3") SetScale(3); else
     if (item == "scale4") SetScale(4); else
     if (item == "scale5") SetScale(5); else
+    if (item == "view_xys") { showxystate = !showxystate; UpdateStatus(); } else
     if (item == "view_grid") ToggleGrid(); else
     if (item == "view_icons") ToggleIcons(); else
     if (item == "view_info") Info(); else
@@ -1594,8 +1598,6 @@ static int TranslateKey(int keycode)
         case 188 : return '<';          // Firefox, Chrome and Safari (Mac)
         case 190 : return '>';          // Firefox, Chrome and Safari (Mac)
         
-        case 0x09: return 295 ; //DOM_VK_TAB -> GLFW_KEY_TAB
-        // GLFW_KEY_ESC is not 255???!!! case 0x1B: return 255 ; //DOM_VK_ESCAPE -> GLFW_KEY_ESC
         case 0x6A: return 313 ; //DOM_VK_MULTIPLY -> GLFW_KEY_KP_MULTIPLY
         case 0x6B: return 315 ; //DOM_VK_ADD -> GLFW_KEY_KP_ADD
         case 0x6D: return 314 ; //DOM_VK_SUBTRACT -> GLFW_KEY_KP_SUBTRACT
@@ -1761,6 +1763,8 @@ int OnKeyChanged(int keycode, int action)
     switch (ch) {
         case 13  : StartStop(); break;
         case ' ' : Next(); break;
+        case 9   : Step(); break;
+        case 8   : if (shift_down) ClearOutsideSelection(); else ClearSelection(); break;
         case '_' : GoSlower(); break;
         case '-' : GoSlower(); break;
         case '+' : GoFaster(); break;
@@ -1934,6 +1938,15 @@ static void DoFrame()
             NextGeneration(true);
             UpdatePatternAndStatus();
         }
+        if (autostop && currlayer->algo->isEmpty()) {
+            StopIfGenerating();
+            if (currlayer->currexpo > 0) {
+                SetMessage("Pattern died at or before this generation.");
+            } else {
+                SetMessage("Pattern died at this generation.");
+            }
+            UpdateStatus();
+        }
     }
     
     if (refresh_pattern) {
@@ -1962,7 +1975,7 @@ static void DoFrame()
 
 int EMSCRIPTEN_KEEPALIVE main()
 {
-    SetMessage("This is Golly 4.3 for the web (copyright 2005-2024 The Golly Gang).");
+    SetMessage("This is Golly 5.0 for the web (copyright 2005-2025 The Golly Gang).");
     InitPaths();                // init tempdir, prefsfile, etc
     MAX_MAG = 5;                // maximum cell size = 32x32
     maxhashmem = 300;           // enough for caterpillar
