@@ -6,15 +6,11 @@
     #include "wx/wx.h"      // for all others include the necessary headers
 #endif
 
-#include "wx/dir.h"         // for wxDir
-#include "wx/file.h"        // for wxFile
-#include "wx/filename.h"    // for wxFileName
-
 #include "bigint.h"
 #include "lifealgo.h"
 #include "qlifealgo.h"
 #include "hlifealgo.h"
-#include "util.h"           // for linereader
+#include "util.h"
 
 #include "wxgolly.h"        // for wxGetApp, statusptr, viewptr, bigview
 #include "wxutils.h"        // for BeginProgress, GetString, etc
@@ -31,16 +27,6 @@
 #include "wxlayer.h"        // for currlayer, etc
 #include "wxtimeline.h"     // for TimelineExists, UpdateTimelineBar, etc
 
-#include <stdexcept>        // for std::runtime_error and std::exception
-#include <sstream>          // for std::ostringstream
-
-#ifdef __WXMAC__
-    // we need to convert filepath to decomposed UTF8 so fopen will work
-    #define OPENFILE(filepath) fopen(filepath.fn_str(),"r")
-#else
-    #define OPENFILE(filepath) fopen(filepath.mb_str(wxConvLocal),"r")
-#endif
-
 // This module implements Control menu functions.
 
 // -----------------------------------------------------------------------------
@@ -131,6 +117,7 @@ bool MainFrame::SaveStartingPattern()
 void MainFrame::ResetPattern(bool resetundo)
 {
     if (currlayer->algo->getGeneration() == currlayer->startgen) return;
+    if (viewptr->drawingcells || viewptr->selectingcells) return;
     
     if (generating) {
         command_pending = true;
@@ -613,25 +600,14 @@ bool MainFrame::StepPattern()
     
     if (!IsIconized()) DisplayPattern();
     
-    /* enable this code if we ever implement isPeriodic()
-    if (autostop) {
-        int period = curralgo->isPeriodic();
-        if (period > 0) {
-            if (period == 1) {
-                if (curralgo->isEmpty()) {
-                    statusptr->DisplayMessage(_("Pattern is empty."));
-                } else {
-                    statusptr->DisplayMessage(_("Pattern is stable."));
-                }
-            } else {
-                wxString s;
-                s.Printf(_("Pattern is oscillating (period = %d)."), period);
-                statusptr->DisplayMessage(s);
-            }
-            return false;
+    if (autostop && curralgo->isEmpty()) {
+        if (curralgo->getIncrement() > bigint::one) {
+            statusptr->DisplayMessage(_("Pattern died at or before this generation."));
+        } else {
+            statusptr->DisplayMessage(_("Pattern died at this generation."));
         }
+        return false;
     }
-    */
     
     return true;
 }
@@ -1629,679 +1605,3 @@ void MainFrame::ChangeAlgorithm(algo_type newalgotype, const wxString& newrule,
         currlayer->undoredo->RememberAlgoChange(oldalgo, oldrule);
     }
 }
-
-// -----------------------------------------------------------------------------
-
-static wxString CreateTABLE(const wxString& tablepath)
-{
-    wxString contents = wxT("\n@TABLE\n\n");
-    // append contents of .table file
-    FILE* f = OPENFILE(tablepath);
-    if (f) {
-        const int MAXLINELEN = 4095;
-        char linebuf[MAXLINELEN + 1];
-        linereader reader(f);
-        while (true) {
-            if (reader.fgets(linebuf, MAXLINELEN) == 0) break;
-            contents += wxString(linebuf, wxConvLocal);
-            contents += wxT("\n");
-        }
-        reader.close();
-    } else {
-        std::ostringstream oss;
-        oss << "Could not read .table file:\n" << tablepath.mb_str(wxConvLocal);
-        throw std::runtime_error(oss.str().c_str());
-    }
-    return contents;
-}
-
-// -----------------------------------------------------------------------------
-
-static wxString CreateEmptyTABLE(const wxString& folder, const wxString& prefix,
-                                 const wxSortedArrayString& allfiles)
-{
-    // create a valid table that does nothing
-    wxString contents = wxT("\nThis file contains colors and/or icons shared by ");
-    contents += prefix;
-    contents += wxT("-* rules.\n");
-    contents += wxT("\n@TABLE\n\n");
-
-    // search allfiles for 1st prefix-*.table/tree file and extract numstates and neighborhood
-    wxString numstates, neighborhood;
-    for (size_t n = 0; n < allfiles.GetCount(); n++) {
-        wxString filename = allfiles[n];
-        if (filename.EndsWith(wxT(".table")) || filename.EndsWith(wxT(".tree"))) {
-            if (prefix == filename.BeforeLast('-')) {
-                wxString filepath = folder + filename;
-                FILE* f = OPENFILE(filepath);
-                if (f) {
-                    const int MAXLINELEN = 4095;
-                    char linebuf[MAXLINELEN + 1];
-                    linereader reader(f);
-                    while (true) {
-                        if (reader.fgets(linebuf, MAXLINELEN) == 0) break;
-                        if (strncmp(linebuf, "n_states:", 9) == 0) {
-                            numstates = wxString(linebuf,wxConvLocal) + wxT("\n");
-                        } else if (strncmp(linebuf, "num_states=", 11) == 0) {
-                            // convert to table syntax
-                            numstates = wxT("n_states:") + wxString(linebuf+11,wxConvLocal);
-                            numstates += wxT("\n");
-                        } else if (strncmp(linebuf, "neighborhood:", 13) == 0) {
-                            neighborhood = wxString(linebuf,wxConvLocal) + wxT("\n");
-                            break;
-                        } else if (strncmp(linebuf, "num_neighbors=", 14) == 0) {
-                            // convert to table syntax
-                            neighborhood = wxT("neighborhood:");
-                            if (linebuf[14] == '4')
-                                neighborhood += wxT("vonNeumann\n");
-                            else
-                                neighborhood += wxT("Moore\n");
-                            break;
-                        }
-                    }
-                    reader.close();
-                } else {
-                    std::ostringstream oss;
-                    oss << "Could not read .table/tree file:\n" << filepath.mb_str(wxConvLocal);
-                    throw std::runtime_error(oss.str().c_str());
-                }
-            }
-        }
-    }
-    
-    if (numstates.length() == 0) {
-        numstates = wxT("n_states:256\n");
-        wxString msg = _("Could not find ") + prefix;
-        msg += _("-*.table/tree to set n_states in ");
-        msg += prefix;
-        msg += _("-shared.rule.");
-        Warning(msg);
-    }
-    
-    contents += numstates;
-    contents += neighborhood;
-    contents += wxT("symmetries:none\n");   // anything valid would do
-    contents += wxT("# do nothing\n");      // no transitions
-
-    return contents;
-}
-
-// -----------------------------------------------------------------------------
-
-static wxString CreateTREE(const wxString& treepath)
-{
-    wxString contents = wxT("\n@TREE\n\n");
-    // append contents of .tree file
-    FILE* f = OPENFILE(treepath);
-    if (f) {
-        const int MAXLINELEN = 4095;
-        char linebuf[MAXLINELEN + 1];
-        linereader reader(f);
-        while (true) {
-            if (reader.fgets(linebuf, MAXLINELEN) == 0) break;
-            contents += wxString(linebuf, wxConvLocal);
-            contents += wxT("\n");
-        }
-        reader.close();
-    } else {
-        std::ostringstream oss;
-        oss << "Could not read .tree file:\n" << treepath.mb_str(wxConvLocal);
-        throw std::runtime_error(oss.str().c_str());
-    }
-    return contents;
-}
-
-// -----------------------------------------------------------------------------
-
-static wxString CreateCOLORS(const wxString& colorspath)
-{
-    wxString contents = wxT("\n@COLORS\n\n");
-    FILE* f = OPENFILE(colorspath);
-    if (f) {
-        const int MAXLINELEN = 4095;
-        char linebuf[MAXLINELEN + 1];
-        linereader reader(f);
-        while (true) {
-            if (reader.fgets(linebuf, MAXLINELEN) == 0) break;
-            int skip = 0;
-            if (strncmp(linebuf, "color", 5) == 0 ||
-                strncmp(linebuf, "gradient", 8) == 0) {
-                // strip off everything before 1st digit
-                while (linebuf[skip] && (linebuf[skip] < '0' || linebuf[skip] > '9')) {
-                    skip++;
-                }
-            }
-            contents += wxString(linebuf + skip, wxConvLocal);
-            contents += wxT("\n");
-        }
-        reader.close();
-    } else {
-        std::ostringstream oss;
-        oss << "Could not read .colors file:\n" << colorspath.mb_str(wxConvLocal);
-        throw std::runtime_error(oss.str().c_str());
-    }
-    return contents;
-}
-
-// -----------------------------------------------------------------------------
-
-static wxString CreateStateColors(wxImage image, int numicons)
-{
-    wxString contents = wxT("\n@COLORS\n\n");
-    
-    // if the last icon has only 1 color then assume it is the extra 15x15 icon
-    // supplied to set the color of state 0
-    if (numicons > 1) {
-        wxImage icon = image.GetSubImage(wxRect((numicons-1)*15, 0, 15, 15));
-        if (icon.CountColours(1) == 1) {
-            unsigned char* idata = icon.GetData();
-            unsigned char R = idata[0];
-            unsigned char G = idata[1];
-            unsigned char B = idata[2];
-            contents += wxString::Format(wxT("0 %d %d %d\n"), R, G, B);
-            numicons--;
-        }
-    }
-    
-    // set non-icon colors for each live state to the average of the non-black pixels
-    // in each 15x15 icon (note we've skipped the extra icon detected above)
-    for (int i = 0; i < numicons; i++) {
-        wxImage icon = image.GetSubImage(wxRect(i*15, 0, 15, 15));
-        int nbcount = 0;   // non-black pixels
-        int totalR = 0;
-        int totalG = 0;
-        int totalB = 0;
-        unsigned char* idata = icon.GetData();
-        for (int y = 0; y < 15; y++) {
-            for (int x = 0; x < 15; x++) {
-                long pos = (y * 15 + x) * 3;
-                unsigned char R = idata[pos];
-                unsigned char G = idata[pos+1];
-                unsigned char B = idata[pos+2];
-                if (R > 0 || G > 0 || B > 0) {
-                    // non-black pixel
-                    nbcount++;
-                    totalR += R;
-                    totalG += G;
-                    totalB += B;
-                }
-            }
-        }
-        if (nbcount > 0) {
-            contents += wxString::Format(wxT("%d %d %d %d\n"), i+1, totalR/nbcount, totalG/nbcount, totalB/nbcount);
-        } else {
-            // unlikely, but avoid div by zero
-            contents += wxString::Format(wxT("%d 0 0 0\n"), i+1);
-        }
-    }
-    
-    return contents;
-}
-
-// -----------------------------------------------------------------------------
-
-static wxString hex2(int i)
-{
-    // convert given number from 0..255 into 2 hex digits
-    wxString result = wxT("xx");
-    const char* hexdigit = "0123456789ABCDEF";
-    result[0] = hexdigit[i / 16];
-    result[1] = hexdigit[i % 16];
-    return result;
-}
-
-// -----------------------------------------------------------------------------
-
-static wxString CreateXPM(const wxString& iconspath, wxImage image, int size, int numicons)
-{
-    // create XPM data for given set of icons
-    wxString contents = wxT("\nXPM\n");
-    
-    int charsperpixel = 1;
-    const char* cindex = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
-    wxImageHistogram histogram;
-    int numcolors = image.ComputeHistogram(histogram);
-    if (numcolors > 256) {
-        std::ostringstream oss;
-        oss << "Image in " << iconspath.mb_str(wxConvLocal) << " has more than 256 colors.";
-        throw std::runtime_error(oss.str().c_str());
-    }
-    if (numcolors > 26) charsperpixel = 2;   // AABA..PA, ABBB..PB, ... , APBP..PP
-    
-    contents += wxT("/* width height num_colors chars_per_pixel */\n");
-    contents += wxString::Format(wxT("\"%d %d %d %d\"\n"), size, size*numicons, numcolors, charsperpixel);
-    
-    contents += wxT("/* colors */\n");
-    int n = 0;
-    for (wxImageHistogram::iterator entry = histogram.begin(); entry != histogram.end(); ++entry) {
-        unsigned long key = entry->first;
-        unsigned char R = (key & 0xFF0000) >> 16;
-        unsigned char G = (key & 0x00FF00) >> 8;
-        unsigned char B = (key & 0x0000FF);
-        if (R == 0 && G == 0 && B == 0) {
-            // nicer to show . or .. for black pixels
-            contents += wxT("\".");
-            if (charsperpixel == 2) contents += wxT(".");
-            contents += wxT(" c #000000\"\n");
-        } else {
-            wxString hexcolor = wxT("#");
-            hexcolor += hex2(R);
-            hexcolor += hex2(G);
-            hexcolor += hex2(B);
-            contents += wxT("\"");
-            if (charsperpixel == 1) {
-                contents += cindex[n];
-            } else {
-                contents += cindex[n % 16];
-                contents += cindex[n / 16];
-            }
-            contents += wxT(" c ");
-            contents += hexcolor;
-            contents += wxT("\"\n");
-        }
-        n++;
-    }
-    
-    for (int i = 0; i < numicons; i++) {
-        contents += wxString::Format(wxT("/* icon for state %d */\n"), i+1);
-        wxImage icon = image.GetSubImage(wxRect(i*15, 0, size, size));
-        unsigned char* idata = icon.GetData();
-        for (int y = 0; y < size; y++) {
-            contents += wxT("\"");
-            for (int x = 0; x < size; x++) {
-                long pos = (y * size + x) * 3;
-                unsigned char R = idata[pos];
-                unsigned char G = idata[pos+1];
-                unsigned char B = idata[pos+2];
-                if (R == 0 && G == 0 && B == 0) {
-                    // nicer to show . or .. for black pixels
-                    contents += wxT(".");
-                    if (charsperpixel == 2) contents += wxT(".");
-                } else {
-                    n = 0;
-                    unsigned long thisRGB = wxImageHistogram::MakeKey(R,G,B);
-                    for (wxImageHistogram::iterator entry = histogram.begin(); entry != histogram.end(); ++entry) {
-                        if (thisRGB == entry->first) break;
-                        n++;
-                    }
-                    if (charsperpixel == 1) {
-                        contents += cindex[n];
-                    } else {
-                        contents += cindex[n % 16];
-                        contents += cindex[n / 16];
-                    }
-                }
-            }
-            contents += wxT("\"\n");
-        }
-    }
-    
-    return contents;
-}
-
-// -----------------------------------------------------------------------------
-
-static wxString CreateICONS(const wxString& iconspath, bool nocolors)
-{
-    wxString contents = wxT("\n@ICONS\n");
-    wxImage image;
-    if (image.LoadFile(iconspath)) {
-        int wd = image.GetWidth();
-        int ht = image.GetHeight();
-        if (ht != 15 && ht != 22) {
-            std::ostringstream oss;
-            oss << "Image in " << iconspath.mb_str(wxConvLocal) <<
-                " has incorrect height (should be 15 or 22).";
-            throw std::runtime_error(oss.str().c_str());
-        }
-        if (wd % 15 > 0) {
-            std::ostringstream oss;
-            oss << "Image in " << iconspath.mb_str(wxConvLocal) <<
-                " has incorrect width (should be multiple of 15).";
-            throw std::runtime_error(oss.str().c_str());
-        }
-        int numicons = wd / 15;
-        
-        // WARNING: MultiColorImage must be called 1st in the next test because
-        // we want image to be converted to black-and-white if it only uses 2 colors
-        // (for compatibility with Golly 2.4 and older)
-        if (MultiColorImage(image) && nocolors) {
-            // the .icons file is multi-color and there was no .colors file,
-            // so prepend a @COLORS section that sets non-icon colors
-            contents = CreateStateColors(image.GetSubImage(wxRect(0,0,wd,15)), numicons) + contents;
-        }
-        
-        if (ht == 15) {
-            contents += CreateXPM(iconspath, image, 15, numicons);
-        } else {
-            contents += CreateXPM(iconspath, image.GetSubImage(wxRect(0,0,wd,15)), 15, numicons);
-            contents += CreateXPM(iconspath, image.GetSubImage(wxRect(0,15,wd,7)), 7, numicons);
-        }
-    } else {
-        std::ostringstream oss;
-        oss << "Could not load image from .icons file:\n" << iconspath.mb_str(wxConvLocal);
-        throw std::runtime_error(oss.str().c_str());
-    }
-    return contents;
-}
-
-// -----------------------------------------------------------------------------
-
-static void CreateOneRule(const wxString& rulefile, const wxString& folder,
-                          const wxSortedArrayString& allfiles, wxString& htmlinfo)
-{
-    wxString tabledata, treedata, colordata, icondata;
-    wxString rulename = rulefile.BeforeLast('.');
-    
-    if (rulename.EndsWith(wxT("-shared"))) {
-        // create a .rule file with colors and/or icons shared by other .rule files
-        wxString prefix = rulename.BeforeLast('-');
-        
-        tabledata = CreateEmptyTABLE(folder, prefix, allfiles);
-        
-        wxString sharedcolors = prefix + wxT(".colors");
-        if (allfiles.Index(sharedcolors) != wxNOT_FOUND)
-            colordata = CreateCOLORS(folder + sharedcolors);
-
-        wxString sharedicons = prefix + wxT(".icons");
-        if (allfiles.Index(sharedicons) != wxNOT_FOUND)
-            icondata = CreateICONS(folder + sharedicons, colordata.length() == 0);        
-    
-    } else {
-        wxString tablefile = rulename + wxT(".table");
-        wxString treefile = rulename + wxT(".tree");
-        wxString colorsfile = rulename + wxT(".colors");
-        wxString iconsfile = rulename + wxT(".icons");
-        
-        if (allfiles.Index(tablefile) != wxNOT_FOUND)
-            tabledata = CreateTABLE(folder + tablefile);
-        
-        if (allfiles.Index(treefile) != wxNOT_FOUND)
-            treedata = CreateTREE(folder + treefile);
-        
-        if (allfiles.Index(colorsfile) != wxNOT_FOUND)
-            colordata = CreateCOLORS(folder + colorsfile);
-        
-        if (allfiles.Index(iconsfile) != wxNOT_FOUND)
-            icondata = CreateICONS(folder + iconsfile, colordata.length() == 0);
-    }
-    
-    wxString contents = wxT("@RULE ") + rulename + wxT("\n");
-    contents += tabledata;
-    contents += treedata;
-    contents += colordata;
-    contents += icondata;
-    
-    // write contents to .rule file
-    wxString rulepath = folder + rulefile;
-    wxFile outfile(rulepath, wxFile::write);
-    if (outfile.IsOpened()) {
-        outfile.Write(contents);
-        outfile.Close();
-    } else {
-        std::ostringstream oss;
-        oss << "Could not create rule file:\n" << rulepath.mb_str(wxConvLocal);
-        throw std::runtime_error(oss.str().c_str());
-    }
-    
-    // append created file to htmlinfo
-    htmlinfo += _("<a href=\"open:");
-    htmlinfo += folder;
-    htmlinfo += rulefile;
-    htmlinfo += _("\">");
-    htmlinfo += rulefile;
-    htmlinfo += _("</a><br>\n");
-}
-
-// -----------------------------------------------------------------------------
-
-static bool SharedColorsIcons(const wxString& prefix, const wxSortedArrayString& allfiles)
-{
-    // return true if prefix.colors/icons is shared by at least one prefix-*.table/tree file
-    for (size_t n = 0; n < allfiles.GetCount(); n++) {
-        wxString filename = allfiles[n];
-        if (filename.EndsWith(wxT(".table")) || filename.EndsWith(wxT(".tree"))) {
-            if (prefix == filename.BeforeLast('-')) {
-                return true;
-            }
-        }
-    }
-    
-    // prefix-*.table/tree does not exist in allfiles
-    return false;
-}
-
-// -----------------------------------------------------------------------------
-
-static int ConvertRules(const wxString& folder, bool supplied, wxString& htmlinfo)
-{
-    wxString filename, rulefile, rulename;
-    int depcount = 0;
-
-    if (!wxFileName::DirExists(folder)) {
-        // this might happen if user deleted/renamed folder while Golly is running
-        std::ostringstream oss;
-        oss << "Directory does not exist:\n" << folder.mb_str(wxConvLocal);
-        throw std::runtime_error(oss.str().c_str());
-    }
-    
-    wxDir dir(folder);
-    if (!dir.IsOpened()) {
-        std::ostringstream oss;
-        oss << "Failed to open directory:\n" << folder.mb_str(wxConvLocal);
-        throw std::runtime_error(oss.str().c_str());
-    }
-
-    htmlinfo += wxT("<p>\n");
-    if (supplied) {
-        htmlinfo += _("New .rule files created in the supplied Rules folder:<br>\n(");
-    } else {
-        htmlinfo += _("New .rule files created in your rules folder:<br>\n(");
-    }
-    htmlinfo += folder;
-    htmlinfo += _(")<p>\n");
-    
-    // build an array of all files in the given folder (using a sorted array speeds up Index calls)
-    wxSortedArrayString allfiles;
-    bool found = dir.GetFirst(&filename, wxEmptyString, wxDIR_FILES | wxDIR_HIDDEN);
-    while (found) {
-        allfiles.Add(filename);
-        found = dir.GetNext(&filename);
-    }
-
-    // create an array of candidate .rule files to be created
-    wxSortedArrayString candidates;
-    for (size_t n = 0; n < allfiles.GetCount(); n++) {
-        filename = allfiles[n];
-        rulename = filename.BeforeLast('.');
-        bool colorsicons = filename.EndsWith(wxT(".colors")) || filename.EndsWith(wxT(".icons"));
-        bool tabletree = filename.EndsWith(wxT(".table")) || filename.EndsWith(wxT(".tree"));
-        if (colorsicons || tabletree) {
-            depcount++;
-            if (colorsicons) {
-                if (SharedColorsIcons(rulename, allfiles)) {
-                    // colors and/or icons will be shared by one or more rulename-*.rule files
-                    rulefile = rulename + wxT("-shared.rule");
-                } else {
-                    rulefile = rulename + wxT(".rule");
-                }
-            } else {
-                // .table/tree file
-                rulefile = rulename + wxT(".rule");
-            }
-            // add .rule file to candidates if it hasn't been added yet
-            // and if it doesn't already exist
-            if (candidates.Index(rulefile) == wxNOT_FOUND &&
-                allfiles.Index(rulefile) == wxNOT_FOUND) {
-                candidates.Add(rulefile);
-            }
-        }
-    }
-    
-    // create the new .rule files
-    for (size_t n = 0; n < candidates.GetCount(); n++) {
-        CreateOneRule(candidates[n], folder, allfiles, htmlinfo);
-    }
-    
-    if (candidates.GetCount() == 0) {
-        htmlinfo += _("None.\n");
-    }
-    
-    return depcount;
-}
-
-// -----------------------------------------------------------------------------
-
-static void ShowCreatedRules(wxString& htmlinfo)
-{
-    wxString header = _("<html><title>Converted Rules</title>\n");
-    header += _("<body bgcolor=\"#FFFFCE\">\n");
-    htmlinfo = header + htmlinfo;
-    htmlinfo += _("\n</body></html>");
-
-    wxString htmlfile = tempdir + _("converted-rules.html");
-    wxFile outfile(htmlfile, wxFile::write);
-    if (outfile.IsOpened()) {
-        outfile.Write(htmlinfo);
-        outfile.Close();
-        ShowHelp(htmlfile);
-    } else {
-        Warning(_("Could not create html file:\n") + htmlfile);
-    }
-}
-
-// -----------------------------------------------------------------------------
-
-static void DeleteOldRules(const wxString& folder)
-{
-    if (wxFileName::DirExists(folder)) {
-        wxDir dir(folder);
-        if (dir.IsOpened()) {
-            // build an array of all files in the given folder
-            wxArrayString allfiles;
-            wxString filename;
-            bool found = dir.GetFirst(&filename, wxEmptyString, wxDIR_FILES | wxDIR_HIDDEN);
-            while (found) {
-                allfiles.Add(filename);
-                found = dir.GetNext(&filename);
-            }
-            // delete all the .table/tree/colors/icons files
-            for (size_t n = 0; n < allfiles.GetCount(); n++) {
-                filename = allfiles[n];
-                if ( filename.EndsWith(wxT(".colors")) || filename.EndsWith(wxT(".icons")) ||
-                     filename.EndsWith(wxT(".table")) || filename.EndsWith(wxT(".tree")) ) {
-                    wxRemoveFile(folder + filename);
-                }
-            }
-        }
-    }
-}
-
-// -----------------------------------------------------------------------------
-
-void MainFrame::ConvertOldRules()
-{
-    if (inscript || viewptr->waitingforclick) return;
-    
-    if (generating) {
-        command_pending = true;
-        cmdevent.SetId(ID_CONVERT);
-        Stop();
-        return;
-    }
-    
-    // look for deprecated .table/tree/colors/icons files and create corresponding .rule files
-    
-    wxString htmlinfo;
-    bool aborted = false;
-    int depcount = 0;       // number of deprecated files
-    try {
-        // look in the supplied Rules folder first, then in the user's rules folder
-        depcount += ConvertRules(rulesdir, true, htmlinfo);
-        depcount += ConvertRules(userrules, false, htmlinfo);
-    }
-    catch(const std::exception& e) {
-        // display message set by throw std::runtime_error(...)
-        Warning(wxString(e.what(),wxConvLocal));
-        aborted = true;
-        // nice to also show error message in help window
-        htmlinfo += _("\n<p>*** CONVERSION ABORTED DUE TO ERROR ***\n<p>");
-        htmlinfo += wxString(e.what(),wxConvLocal);
-    }
-    
-    // display the results in the help window
-    ShowCreatedRules(htmlinfo);
-    
-    if (!aborted && depcount > 0) {
-        // ask user if it's ok to delete all the deprecated files
-        int answer = wxMessageBox(_("Do you want to delete all the old .table/tree/colors/icons files?"),
-                                  _("Delete deprecated files?"),
-                                  wxICON_QUESTION | wxYES_NO, wxGetActiveWindow());
-        if (answer == wxYES) {
-            DeleteOldRules(rulesdir);
-            DeleteOldRules(userrules);
-        }
-    }
-}
-
-// -----------------------------------------------------------------------------
-
-wxString MainFrame::CreateRuleFiles(const wxSortedArrayString& deprecated,
-                                    const wxSortedArrayString& ziprules)
-{
-    // use the given list of deprecated .table/tree/colors/icons files
-    // (recently extracted from a .zip file and installed in userrules)
-    // to create new .rule files, except those in ziprules (they were in
-    // the .zip file and have already been installed)
-    wxString htmlinfo;
-    bool aborted = false;
-    try {
-        // create an array of candidate .rule files to be created
-        wxString rulefile, filename, rulename;
-        wxSortedArrayString candidates;
-        for (size_t n = 0; n < deprecated.GetCount(); n++) {
-            filename = deprecated[n];
-            rulename = filename.BeforeLast('.');
-            if (filename.EndsWith(wxT(".colors")) || filename.EndsWith(wxT(".icons"))) {
-                if (SharedColorsIcons(rulename, deprecated)) {
-                    // colors and/or icons will be shared by one or more rulename-*.rule files
-                    rulefile = rulename + wxT("-shared.rule");
-                } else {
-                    rulefile = rulename + wxT(".rule");
-                }
-            } else {
-                // .table/tree file
-                rulefile = rulename + wxT(".rule");
-            }
-            // add .rule file to candidates if it hasn't been added yet
-            // and if it isn't in the zip file (ie. already installed)
-            if (candidates.Index(rulefile) == wxNOT_FOUND &&
-                ziprules.Index(rulefile) == wxNOT_FOUND) {
-                candidates.Add(rulefile);
-            }
-        }
-        
-        // create the new .rule files (unlike ConvertRules, here we overwrite any
-        // existing .rule files in case the zip file's contents have changed)
-        for (size_t n = 0; n < candidates.GetCount(); n++) {
-            CreateOneRule(candidates[n], userrules, deprecated, htmlinfo);
-        }
-    }
-    catch(const std::exception& e) {
-        // display message set by throw std::runtime_error(...)
-        Warning(wxString(e.what(),wxConvLocal));
-        aborted = true;
-        // nice to also show error message in help window
-        htmlinfo += _("\n<p>*** CONVERSION ABORTED DUE TO ERROR ***\n<p>");
-        htmlinfo += wxString(e.what(),wxConvLocal);
-    }
-    
-    if (!aborted) {
-        // delete all the deprecated files
-        for (size_t n = 0; n < deprecated.GetCount(); n++) {
-            wxRemoveFile(userrules + deprecated[n]);
-        }
-    }
-    
-    return htmlinfo;
-}
