@@ -49,7 +49,9 @@ private:
     enum {
         ID_BACK_BUTT = wxID_HIGHEST + 1,
         ID_FORWARD_BUTT,
-        ID_CONTENTS_BUTT
+        ID_CONTENTS_BUTT,
+        ID_SMALLER_BUTT,
+        ID_BIGGER_BUTT
     };
     
     // event handlers
@@ -57,6 +59,8 @@ private:
     void OnBackButton(wxCommandEvent& event);
     void OnForwardButton(wxCommandEvent& event);
     void OnContentsButton(wxCommandEvent& event);
+    void OnBiggerButton(wxCommandEvent& event);
+    void OnSmallerButton(wxCommandEvent& event);
     void OnCloseButton(wxCommandEvent& event);
     void OnClose(wxCloseEvent& event);
     
@@ -76,6 +80,8 @@ EVT_ACTIVATE   (                    HelpFrame::OnActivate)
 EVT_BUTTON     (ID_BACK_BUTT,       HelpFrame::OnBackButton)
 EVT_BUTTON     (ID_FORWARD_BUTT,    HelpFrame::OnForwardButton)
 EVT_BUTTON     (ID_CONTENTS_BUTT,   HelpFrame::OnContentsButton)
+EVT_BUTTON     (ID_SMALLER_BUTT,    HelpFrame::OnSmallerButton)
+EVT_BUTTON     (ID_BIGGER_BUTT,     HelpFrame::OnBiggerButton)
 EVT_BUTTON     (wxID_CLOSE,         HelpFrame::OnCloseButton)
 EVT_CLOSE      (                    HelpFrame::OnClose)
 END_EVENT_TABLE()
@@ -165,6 +171,9 @@ HtmlView* htmlwin = NULL;     // html child window
 wxButton* backbutt;           // back button
 wxButton* forwbutt;           // forwards button
 wxButton* contbutt;           // Contents button
+wxButton* smallerbutt;        // smaller text
+wxButton* biggerbutt;         // bigger text
+wxButton* closebutt;          // Close button
 
 long whenactive;              // when help window became active (elapsed millisecs)
 
@@ -211,21 +220,22 @@ HelpFrame::HelpFrame()
     wxBoxSizer* vbox = new wxBoxSizer(wxVERTICAL);
     wxBoxSizer* hbox = new wxBoxSizer(wxHORIZONTAL);
     
-    backbutt = new wxButton(this, ID_BACK_BUTT, _("<"),
-                            wxDefaultPosition, wxSize(40,wxDefaultCoord));
-    hbox->Add(backbutt, 0, wxALL | wxALIGN_LEFT, 10);
-    
-    forwbutt = new wxButton(this, ID_FORWARD_BUTT, _(">"),
-                            wxDefaultPosition, wxSize(40,wxDefaultCoord));
-    hbox->Add(forwbutt, 0, wxTOP | wxBOTTOM | wxALIGN_LEFT, 10);
-    
-    contbutt = new wxButton(this, ID_CONTENTS_BUTT, _("Contents"));
-    hbox->Add(contbutt, 0, wxALL | wxALIGN_LEFT, 10);
-    
-    hbox->AddStretchSpacer(1);
-    
-    wxButton* closebutt = new wxButton(this, wxID_CLOSE, _("Close"));
+    backbutt = new wxButton(this, ID_BACK_BUTT,       _("<"), wxDefaultPosition, wxSize(30,wxDefaultCoord));
+    forwbutt = new wxButton(this, ID_FORWARD_BUTT,    _(">"), wxDefaultPosition, wxSize(30,wxDefaultCoord));
+    contbutt = new wxButton(this, ID_CONTENTS_BUTT,   _("Contents"));
+    smallerbutt = new wxButton(this, ID_SMALLER_BUTT, _("-"), wxDefaultPosition, wxSize(30,wxDefaultCoord));
+    biggerbutt = new wxButton(this, ID_BIGGER_BUTT,   _("+"), wxDefaultPosition, wxSize(30,wxDefaultCoord));
+    closebutt = new wxButton(this, wxID_CLOSE,        _("Close"));
     closebutt->SetDefault();
+    
+    hbox->Add(backbutt, 0, wxLEFT | wxTOP | wxBOTTOM | wxALIGN_LEFT, 10);
+    hbox->AddSpacer(5);
+    hbox->Add(forwbutt, 0, wxTOP | wxBOTTOM | wxALIGN_LEFT, 10);
+    hbox->Add(contbutt, 0, wxLEFT | wxTOP | wxBOTTOM | wxALIGN_LEFT, 10);
+    hbox->Add(smallerbutt, 0, wxLEFT | wxTOP | wxBOTTOM | wxALIGN_LEFT, 10);
+    hbox->AddSpacer(5);
+    hbox->Add(biggerbutt, 0, wxRIGHT | wxTOP | wxBOTTOM | wxALIGN_LEFT, 10);
+    hbox->AddStretchSpacer(1);
     hbox->Add(closebutt, 0, wxALL, 10);
     
     vbox->Add(hbox, 0, wxALL | wxEXPAND | wxALIGN_TOP, 0);
@@ -388,6 +398,26 @@ void HelpFrame::OnContentsButton(wxCommandEvent& WXUNUSED(event))
 
 // -----------------------------------------------------------------------------
 
+void HelpFrame::OnSmallerButton(wxCommandEvent& WXUNUSED(event))
+{
+    if ( helpfontsize > minfontsize ) {
+        helpfontsize--;
+        htmlwin->ChangeFontSizes(helpfontsize);
+    }
+}
+
+// -----------------------------------------------------------------------------
+
+void HelpFrame::OnBiggerButton(wxCommandEvent& WXUNUSED(event))
+{
+    if ( helpfontsize < maxfontsize ) {
+        helpfontsize++;
+        htmlwin->ChangeFontSizes(helpfontsize);
+    }
+}
+
+// -----------------------------------------------------------------------------
+
 void HelpFrame::OnCloseButton(wxCommandEvent& WXUNUSED(event))
 {
     Close(true);
@@ -701,13 +731,7 @@ void GetURL(const wxString& url)
     if ( !helpptr->DownloadURL(fullurl, filepath) ) return;
     
     if (htmlwin->editlink) {
-        if (IsRuleFile(filename) && filename.Lower().EndsWith(wxT(".icons"))) {
-            // let user see b&w image in .icons file
-            mainptr->Raise();
-            mainptr->OpenFile(filepath);
-        } else {
-            mainptr->EditFile(filepath);
-        }
+        mainptr->EditFile(filepath);
         return;
     }
     
@@ -749,24 +773,18 @@ void UnzipFile(const wxString& zippath, const wxString& entry)
     wxString tempfile = tempdir + filename;
     
     if ( IsRuleFile(filename) ) {
-        // rule-related file should have already been extracted and installed
+        // .rule file should have already been extracted and installed
         // into userrules, so check that file exists and load rule
         wxString rulefile = userrules + filename;
         if (wxFileExists(rulefile)) {
             if (htmlwin->editlink) {
-                if (filename.Lower().EndsWith(wxT(".icons"))) {
-                    // let user see b&w image in .icons file
-                    mainptr->Raise();
-                    mainptr->OpenFile(rulefile);
-                } else {
-                    mainptr->EditFile(rulefile);
-                }
+                mainptr->EditFile(rulefile);
             } else {         
                 // load corresponding .rule file
                 LoadRule(filename.BeforeLast('.'));
             }
         } else {
-            Warning(_("Rule-related file was not installed:\n") + rulefile);
+            Warning(_("Rule file was not installed:\n") + rulefile);
         }
         
     } else if ( mainptr->ExtractZipEntry(zippath, entry, tempfile) ) {
@@ -1310,9 +1328,7 @@ void ShowAboutBox()
     wxDialog dlg(mainptr, wxID_ANY, wxString(_("About Golly")));
     
     HtmlView* html = new HtmlView(&dlg, wxID_ANY, wxDefaultPosition,
-#if defined(__WXMAC__)
-                                  wxSize(400, 330),
-#elif defined(__WXGTK__)
+#ifdef __WXGTK__
                                   wxSize(450, 370),
 #else
                                   wxSize(400, 350),
@@ -1320,7 +1336,7 @@ void ShowAboutBox()
                                   wxHW_SCROLLBAR_NEVER | wxSUNKEN_BORDER);
     html->SetBorders(0);
 #ifdef __WXMAC__
-    html->SetFontSizes(helpfontsize);
+    html->SetFontSizes(13); // must be a fixed size (not helpfontsize)
 #endif
     html->CheckAndLoad(_("Help/about.html"));
     
