@@ -32,6 +32,10 @@ extern wxString tempdir;         // path of directory for temporary data
 extern wxString rulesdir;        // path of directory for app's rule data
 extern wxString userrules;       // path of directory for user's rule data
 extern wxString downloaddir;     // path of directory for downloaded data
+extern wxString userdir;         // path of directory added by user
+
+// userdir is initially set to this illegal directory path (can't be "")
+const wxString baddir = wxT(":\\/:");
 
 extern int debuglevel;           // for displaying debug info if > 0
 
@@ -63,6 +67,7 @@ extern bool initautofit;         // initial autofit setting
 extern bool inithyperspeed;      // initial hyperspeed setting
 extern bool initshowhashinfo;    // initial showhashinfo setting
 extern bool showpopulation;      // show population counts while generating?
+extern bool autostop;            // automatically stop generating if pattern dies?
 extern bool savexrle;            // save RLE file using XRLE format?
 extern bool showtips;            // show button tips?
 extern bool showtool;            // show tool bar?
@@ -71,6 +76,7 @@ extern bool showedit;            // show edit bar?
 extern bool showallstates;       // show all cell states in edit bar?
 extern bool showstatus;          // show status bar?
 extern bool showexact;           // show exact numbers in status bar?
+extern bool showxystate;         // show state of cell at XY location?
 extern bool showscrollbars;      // show scroll bars?
 extern bool showtimeline;        // show timeline bar?
 extern bool showgridlines;       // display grid lines?
@@ -215,7 +221,7 @@ typedef enum {
     DO_SW,                        // scroll SW
     DO_SELALL,                    // select all
     DO_SETBASE,                   // set base step...
-    DO_FILEDIR,                   // set file folder...
+    DO_SETFOLDER,                 // set folder...
     DO_SETGEN,                    // set generation...
     DO_SETCOLORS,                 // set layer colors...
     DO_SETRULE,                   // set rule...
@@ -241,6 +247,7 @@ typedef enum {
     DO_SHOWTIME,                  // show timeline
     DO_TIMING,                    // show timing
     DO_SHOWTOOL,                  // show tool bar
+    DO_SHOWXYSTATE,               // show XY state
     DO_SHRINKFIT,                 // shrink and fit
     DO_SHRINK,                    // shrink selection
     DO_SLOWER,                    // slower
@@ -248,6 +255,7 @@ typedef enum {
     DO_STACK,                     // stack layers
     DO_STARTSTOP,                 // start/stop generating
     DO_RECORD,                    // start/stop recording
+    DO_AUTOSTOP,                  // stop if dead
     DO_SYNCCURS,                  // synchronize cursors
     DO_SYNCVIEWS,                 // synchronize views
     DO_TILE,                      // tile layers
