@@ -258,7 +258,7 @@ TimelineBar::TimelineBar(wxWindow* parent, wxCoord xorg, wxCoord yorg, int wd, i
     if (slider == NULL) Fatal(_("Failed to create timeline slider!"));
 #ifdef __WXMAC__
     slider->SetWindowVariant(wxWINDOW_VARIANT_SMALL);
-    slider->Move(x, y+1);
+    slider->Move(x, y-1);
 #endif
     xpos = x + sliderwd;
     
