@@ -16,6 +16,7 @@
 #include "wxscript.h"      // for inscript, showprogress, PassKeyToScript
 #include "wxprefs.h"       // for allowbeep
 #include "wxutils.h"
+#include <random>
 
 // -----------------------------------------------------------------------------
 
@@ -525,34 +526,7 @@ void EndProgress()
 
 void DrawRect(wxDC& dc, wxRect& rect)
 {
-    #ifdef __WXMAC__
-        #if wxCHECK_VERSION(3,1,5)
-            // EnableOffset fix no longer works in 3.1.5!
-            if (scalefactor > 1.0) {
-                rect.x++;
-                rect.y++;
-                rect.width--;
-                rect.height--;
-            }
-        #else
-            // fix DrawRectangle problem on Retina screens
-            if (scalefactor > 1.0) dc.GetGraphicsContext()->EnableOffset(true);
-        #endif
-    #endif
-
     dc.DrawRectangle(rect);
-
-    #ifdef __WXMAC__
-        #if wxCHECK_VERSION(3,1,5)
-            if (scalefactor > 1.0) {
-                // restore rect
-                rect.x--;
-                rect.y--;
-                rect.width++;
-                rect.height++;
-            }
-        #endif
-    #endif
 }
 
 // -----------------------------------------------------------------------------
@@ -562,9 +536,7 @@ void FillRect(wxDC& dc, wxRect& rect, wxBrush& brush)
     // set pen transparent so brush fills rect
     dc.SetPen(*wxTRANSPARENT_PEN);
     dc.SetBrush(brush);
-    
-    dc.DrawRectangle(rect);     // don't call DrawRect(dc,rect) here!
-    
+    dc.DrawRectangle(rect);
     dc.SetBrush(wxNullBrush);   // restore brush
     dc.SetPen(wxNullPen);       // restore pen
 }
@@ -671,9 +643,16 @@ bool IsRuleFile(const wxString& filename)
     wxString ext = filename.AfterLast('.');
     // if filename has no extension then ext == filename
     if (ext == filename) return false;
-    return ( ext.IsSameAs(wxT("rule"),false) ||
-             ext.IsSameAs(wxT("table"),false) ||
-             ext.IsSameAs(wxT("tree"),false) ||
-             ext.IsSameAs(wxT("colors"),false) ||
-             ext.IsSameAs(wxT("icons"),false) );
+    return ( ext.IsSameAs(wxT("rule"),false) );
+}
+
+// -----------------------------------------------------------------------------
+
+int golly_rand()
+{
+   static std::random_device dev;
+   static std::mt19937 rng(dev());
+   static std::uniform_int_distribution<std::mt19937::result_type>
+                                                      dist31(0,0x7fffffff);
+   return dist31(rng);
 }
